aboutsummaryrefslogtreecommitdiffstats
path: root/epan/wslua
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2014-07-03 13:30:12 -0700
committerGuy Harris <guy@alum.mit.edu>2014-07-03 20:30:42 +0000
commit1c297771c3039157cad8cf43344af0f6ae51146c (patch)
tree622ccb0134663a3e68263eec0c27026858e6b1d0 /epan/wslua
parent7dd27dbff850bbfbd94806c2c549e9eebe1fa707 (diff)
Rename and move ui/stat_menu.h to epan/stat_groups.h.
The groups are, technically, independent of the notion of a menu, and, if we have mechanisms by which taps that are not only GUI toolkit-independent but independent of the *existence* of a GUI can be registered, they might want to register themselves in a group just in case they're running in a program that has a GUI. Also, this might fix the Debian package build. Change-Id: I29435681e79748fd4f2e0c5ac872cd11f831d172 Reviewed-on: https://code.wireshark.org/review/2830 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/wslua')
-rw-r--r--epan/wslua/CMakeLists.txt2
-rw-r--r--epan/wslua/Makefile.am2
-rwxr-xr-xepan/wslua/make-init-lua.pl8
3 files changed, 6 insertions, 6 deletions
diff --git a/epan/wslua/CMakeLists.txt b/epan/wslua/CMakeLists.txt
index ca919b8572..6bb30756d7 100644
--- a/epan/wslua/CMakeLists.txt
+++ b/epan/wslua/CMakeLists.txt
@@ -106,7 +106,7 @@ ADD_CUSTOM_COMMAND(
${CMAKE_SOURCE_DIR}/epan/ftypes/ftypes.h
${CMAKE_SOURCE_DIR}/wiretap/wtap.h
${CMAKE_SOURCE_DIR}/epan/epan.h
- ${CMAKE_SOURCE_DIR}/ui/stat_menu.h
+ ${CMAKE_SOURCE_DIR}/epan/stat_groups.h
)
add_custom_target(
diff --git a/epan/wslua/Makefile.am b/epan/wslua/Makefile.am
index 7e677dbec1..85203ced2d 100644
--- a/epan/wslua/Makefile.am
+++ b/epan/wslua/Makefile.am
@@ -122,7 +122,7 @@ declare_wslua.h: make-reg.pl $(wslua_modules) taps_wslua.c
dummy:
touch dummy
-init.lua: template-init.lua make-init-lua.pl ../ftypes/ftypes.h ../../wiretap/wtap.h ../proto.h ../../ui/stat_menu.h
+init.lua: template-init.lua make-init-lua.pl ../ftypes/ftypes.h ../../wiretap/wtap.h ../proto.h ../stat_groups.h
$(PERL) $(srcdir)/make-init-lua.pl $(top_srcdir) $(srcdir)/template-init.lua > init.lua
checkapi:
diff --git a/epan/wslua/make-init-lua.pl b/epan/wslua/make-init-lua.pl
index 336d6670bd..082fb5264d 100755
--- a/epan/wslua/make-init-lua.pl
+++ b/epan/wslua/make-init-lua.pl
@@ -204,7 +204,7 @@ while(<PROTO_H>) {
close PROTO_H;
#
# Extract values from stat_menu.h:
#
# MENU_X_X values for register_stat_group_t
#
@@ -212,9 +212,9 @@ close PROTO_H;
$menu_groups .= "-- menu groups for register_menu\n";
my $menu_i = 0;
-open STAT_MENU, "< $WSROOT/ui/stat_menu.h" or die "cannot open '$WSROOT/ui/stat_menu.h': $!";
+open STAT_GROUPS, "< $WSROOT/epan/stat_groups.h" or die "cannot open '$WSROOT/epan/stat_groups.h': $!";
my $foundit = 0;
-while(<STAT_MENU>) {
+while(<STAT_GROUPS>) {
# need to skip matching words in comments, and get to the enum
if (/^typedef enum {/) { $foundit = 1; }
# the problem here is we need to pick carefully, so we don't break existing scripts
@@ -224,7 +224,7 @@ while(<STAT_MENU>) {
$menu_i++;
}
}
-close STAT_MENU;
+close STAT_GROUPS;
$bases_table .= "}\n\n";
@@ -204,7 +204,7 @@ while(<PROTO_H>) {
close PROTO_H;
#
-# Extract values from stat_menu.h:
+# Extract values from stat_groups.h:
#
# MENU_X_X values for register_stat_group_t